#
# spec file for package perl-Crypt-SSLeay
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Crypt-SSLeay
VCS: https://src.suse.de/SLFO-pool/perl-Crypt-SSLeay#616315e0fb3248f9e1a8f21a8b4e8b573da65628eb4b29876d511d546a6da288
Version:        0.72
Release:        160000.2.4
%define cpan_name Crypt-SSLeay
Summary:        OpenSSL support for LWP
License:        Artistic-2.0
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/N/NA/NANIS/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
Patch0:         no-dot-inc.patch
Patch1:         Crypt-SSLeay-use_TLS_instead_of_SSL.patch
Patch2:         perl-Crypt-SSLeay-tests.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::CBuilder) >= 0.280205
BuildRequires:  perl(LWP::Protocol::https) >= 6.02
BuildRequires:  perl(Path::Class) >= 0.26
BuildRequires:  perl(Try::Tiny) >= 0.19
BuildRequires:  pkgconfig(zlib)
Requires:       perl(LWP::Protocol::https) >= 6.02
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  openssl-devel
Requires:       openssl
# MANUAL END

%description
This Perl module provides support for the HTTPS protocol under LWP, to
allow an LWP::UserAgent object to perform GET, HEAD, and POST requests over
encrypted socket connections. Please see LWP for more information on POST
requests.

The 'Crypt::SSLeay' package provides 'Net::SSL', which, if requested, is
loaded by 'LWP::Protocol::https' for https requests and provides the
necessary SSL glue.

%prep
%autosetup -p1 -n %{cpan_name}-%{version}
find . -type f ! -name \*.pl -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README.md TODO

%changelog
* Mon Mar  4 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Fri Oct  4 2019 pmonrealgonzalez@suse.com
- Fix build: Don't test content of returned version strings
  * Add perl-Crypt-SSLeay-tests.patch
* Fri Oct  4 2019 pmonrealgonzalez@suse.com
- Add missing zlib build dependency, which used to be pulled in
  by libopenssl-devel. The package fails to build since the openssl
  upgrade to 1.1.1 (bsc#1149792)
* Mon Nov 13 2017 vcizek@suse.com
- Disable SSLv2/3 to fix build with OpenSSL 1.1 (bsc#1067188)
  * add Crypt-SSLeay-use_TLS_instead_of_SSL.patch
* Sat Sep 23 2017 coolo@suse.com
- add no-dot-inc.patch inherited from gentoo to build with perl 5.26
- remove Crypt-SSLeay-0.58.patch not applied for a long time
* Wed Apr 15 2015 coolo@suse.com
- updated to 0.72
  see /usr/share/doc/packages/perl-Crypt-SSLeay/Changes
  0.70    2014-04-24 14:53:43 UTC
  - RT #94974: I forgot that `return` just returns from the code block for
    `catch`, not the subroutine so `filter_libs` was still trying to link
    against various libraries even when Devel::CheckLib was not installed.
  0.68    2014-04-24 14:13:07 UTC
  - Previous release did not bump version number in Net::SSL even though there
    was a minor change. Correct that oversight.
  0.66    2014-04-24 14:00:42 UTC
  - Various minor fixes to C code
  - Various fixes to the distribution such as manifest files, additional
    tests, bundled module etc
  - Address RT bugs #94828 and #79212
  0.65_14 2014-04-16 23:55:42 UTC
  - REMINDER: make test WILL FAIL if your OpenSSL is vulnerable to Heartbleed.
  - Add additional functions exposing information that can be obtained via
    SSLeay_version.
  0.65_13 2014-04-15 22:22:43 UTC
  - Work in progress
  - Add ability to query OpenSSL version, add test whether OpenSSL library
    being used is vulnerable to the Heartbleed bug.
  - Assorted fixes to Makefile.PL, most importantly to fix build problems with
    Strawberry Perl.
  0.65_08 2014-04-10 13:40:08 UTC
  - Work in progress
  - In Makefile.PL, use assert_lib to find the libraries against which we can
    actually link rather than passing a big bowl of libs to WriteMakefile.
    Bail out early if we can't link against any of the candidate libraries.
  0.65_07 2014-04-10 12:38:06 UTC
  - Work in progres
  - Make sure t/02-live.t actually uses Net::SSL.
  0.65_06 2014-04-10 10:35:14 UTC
  - Work in progress
  - Address RT bugs #88786, #88269, #78848, and #79477
  - Makefile.PL now respects live-tests and no-live-tests, and allows library
    and header locations to be specified via the command line arguments
    libpath and incpath, respectively.
  - These options can also be specified using the environment variables
    CRYPT_SSLEAY_LIVE_TEST_WANTED
    OPENSSL_LIB
    OPENSSL_INC
  - Also fixed a number of embarrasing logic errors and typos in Makefile.PL
    which were introduced in previous 0.65_xx versions.
  0.65_05 2014-04-04 12:38:21 UTC
  - Work in progress
  - Reorganize Makefile.PL to allow incpath and libpath command line
    arguments. This attempts to address RT #88786, #88269, #79477, and #78848.
    This was supposed to be the next step immediately after drastically
    specifying Makefile.PL. But never got done.
  - Also add encoded version number to openssl-version output.
  0.65_04 2014-04-02 18:03:11 UTC
  - Work in progress
  - Address pull requests from GitHub and bug reports on RT. These address RT
    issues #83764, #86425, #86819, #62133, #82715, #90803
- disable Crypt-SSLeay-0.58.patch as it works without and it's unclear what it
  wants to achieve
* Mon Jun  3 2013 coolo@suse.com
- updated to 0.64
  - Drastically simplify Makefile.PL to resolve RT bugs #61249, #61324,
    [#63553], #68208, and #68084.
  - Forgot to update Changes for 0.63, so this version overrides that.
  - Trying to distinguish between good vs bad zero returns from underlying
    SSL_read/SSL_write broke stuff (see RT bug #78695). Revert to previous
    behavior.
  - Completely re-organize Makefile.PL. I hope these changes will help take
    care of RT bugs #61324, #61249, #63553, and #68084 etc. This is not
    necessarily finished, but I want to see what happens on CPAN Testers at
    this point before making a few other minor changes.
  - Release 0.59_03 as 0.60 so distributions can pick up various fixes. The most
    important one seems to be bug RT #70565. This should take care of bug RT
    [#77167]
  - SSL_read and SSL_write now try to handle incomplete reads/writes (see bug RT
    RT #64054). The current test suite does is not very comprehensive, so caution
    is recommended at this point. Also, if you have good test cases, I would love
    to incorporate them into the distribution.
  - Bump version number and upload to CPAN.
  - Forgot to update Changes for 0.59_01. The following is a combined list of
    the more important fixes incorporated in both.
  - Bug RT #64054: Handle incomplete reads/writes better
  - Bug RT #73754: Add LWP::Protocol::https to PREREQ_PM
  - Bug RT #73755: Crypt-SSLeay does not verify hosts (yet). Don't let that
    cause a failure during tests.
  - Streamline t/02-live.t using Try::Tiny and done_testing
  - Plus assorted related small changes.
  - L<text|scheme:...> is not supported in POD for 5.8.5 and earlier.
  - TODOs in POD should stand out
  - Add /boot/common/ssl and some other directories to unix_ssl_dirs (see bug
    [#60936]).
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Nov 24 2010 chris@computersalat.de
- update to 0.58
  - Bump version number for Crypt::SSLeay to 0.58 and Net::SSL to 2.85 in
    preparation for release.
  - Fix typo in POD is SSLeay.pm s/PEM0encoded/PEM encoded/ (checked
    http://github.com/gitpan/Crypt-SSLeay/blob/9a1582ee1e4d132ae7cf9497bb83144786425d73/SSLeay.pm)
  - Update Changes and TODO. Regenerate README and META.yml. Update package
    author. Minor POD fixes.
  - for more info please see Changes file
- reworked patch
- recreated by cpanspec 1.78
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Tue Jan 13 2009 mrueckert@suse.de
- fix rpmlint warnings
  - repackage as tar.bz2
  - make certs nonexecutable
  - remove outdated conditionals on suse_version 820
- enable testsuite (bnc#465698)
* Thu Apr  3 2008 ug@suse.de
- version to 0.57
- Honour both $ENV{NO_PROXY} and $ENV{no_proxy} in
  Net::SSL::proxy_connect_helper. (Bug #29371 reported by Jan Dubois).
- $@ construction used in Net::SSL::connect was messed up, which could
  lead to sub-optimal error reporting. (Bug #29372 reported by Jan
  Dubois).
- Ensure no proxification is used in t/01-connect.t (which might be the
  reason for all the spurious smoke failures). Bug #29373 reported by,
  you guessed it, Jan Dubois).
- Silence a dubious fopen() warning in SSLeay.xs.
- s/Netware/NetWare/ in Net/SSL.pm platform check
- Improvements to Makefile.PL for dealing with platforms where openssl
  is installed with ./include and ./lib as sibling directories rather
  than child directories. This should allow the code to configure and
  build "out of the box" on Solaris (and probably other proprietary
  platforms).
- Don't carp in LICENSE key addition code in Makefile.PL
* Mon Jul 16 2007 ug@suse.de
- version update to 0.56
  - too many changes. See Changes file for details
* Wed Oct 25 2006 ug@suse.de
- openssl-devel removed from "Requires"
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Nov 12 2005 schwab@suse.de
- Fix crash due to API change in SSL library [#129911].
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Mon Sep  1 2003 ug@suse.de
- initial package
